Learn R Programming

realestateDK (version 0.1.0)

BM010: Property prices in housing market

Description

Property prices in housing market by area, property category, prices of completed transactions and time

Usage

BM010(EJKAT20, OMR20, PRIS20, Tid, lang = "en")

Arguments

EJKAT20

is the property category. Call realestateDK::table_vars("BM010") to see all available parameter settings.

OMR20

is the area. Call realestateDK::table_vars("BM010") to see all available parameter settings.

PRIS20

is the prices of completed transactions. Call realestateDK::table_vars("BM010") to see all available parameter settings.

Tid

is the time. Call realestateDK::table_vars("BM010") to see all available parameter settings.

lang

whether to return the data in english or danish.

Value

a tibble

References

http://rkr.statistikbank.dk/BM010

Examples

Run this code
# NOT RUN {
realestateDK::BM010(EJKAT20 = "1", OMR20 = "00", PRIS20 = "UDBUD", Tid = "1992K1")
# }

Run the code above in your browser using DataLab