Learn R Programming

realestateDK (version 0.1.0)

BM020: Movements in housing market

Description

Movements in housing market by area, property category, type of movement and time

Usage

BM020(BEV20, EJKAT20, OMR20, Tid, lang = "en")

Arguments

BEV20

is the type of movement. Call realestateDK::table_vars("BM020") to see all available parameter settings.

EJKAT20

is the property category. Call realestateDK::table_vars("BM020") to see all available parameter settings.

OMR20

is the area. Call realestateDK::table_vars("BM020") to see all available parameter settings.

Tid

is the time. Call realestateDK::table_vars("BM020") to see all available parameter settings.

lang

whether to return the data in english or danish.

Value

a tibble

References

http://rkr.statistikbank.dk/BM020

Examples

Run this code
# NOT RUN {
realestateDK::BM020(BEV20 = "SALG", EJKAT20 = "1", OMR20 = "00", Tid = "2004K1")
# }

Run the code above in your browser using DataLab