powered by
Movements in housing market by postal code, property category, type of movement and time
BM021(BEV20, EJKAT20, PNR20, Tid, lang = "en")
is the type of movement. Call realestateDK::table_vars("BM021") to see all available parameter settings.
is the property category. Call realestateDK::table_vars("BM021") to see all available parameter settings.
is the postal code. Call realestateDK::table_vars("BM021") to see all available parameter settings.
is the time. Call realestateDK::table_vars("BM021") to see all available parameter settings.
whether to return the data in english or danish.
a tibble
http://rkr.statistikbank.dk/BM021
# NOT RUN { realestateDK::BM021(BEV20 = "SALG", EJKAT20 = "1", PNR20 = "1000", Tid = "2004K1") # }
Run the code above in your browser using DataLab