Learn R Programming

realestateDK (version 0.1.0)

UDB010: Housing market

Description

Housing market by area, property category, dwellings and time

Usage

UDB010(BOLA20, EJKAT20, OMR20, Tid, lang = "en")

Arguments

BOLA20

is the dwellings. Call realestateDK::table_vars("UDB010") to see all available parameter settings.

EJKAT20

is the property category. Call realestateDK::table_vars("UDB010") to see all available parameter settings.

OMR20

is the area. Call realestateDK::table_vars("UDB010") to see all available parameter settings.

Tid

is the time. Call realestateDK::table_vars("UDB010") to see all available parameter settings.

lang

whether to return the data in english or danish.

Value

a tibble

References

http://rkr.statistikbank.dk/UDB010

Examples

Run this code
# NOT RUN {
realestateDK::UDB010(BOLA20 = "6", EJKAT20 = "1", OMR20 = "00", Tid = "2004M01")
# }

Run the code above in your browser using DataLab