Learn R Programming

realestateDK (version 0.1.0)

UDB020: Property prices

Description

Property prices by area, property category, prices and time

Usage

UDB020(BOLB20, EJKAT20, OMR20, Tid, lang = "en")

Arguments

BOLB20

is the prices. Call realestateDK::table_vars("UDB020") to see all available parameter settings.

EJKAT20

is the property category. Call realestateDK::table_vars("UDB020") to see all available parameter settings.

OMR20

is the area. Call realestateDK::table_vars("UDB020") to see all available parameter settings.

Tid

is the time. Call realestateDK::table_vars("UDB020") to see all available parameter settings.

lang

whether to return the data in english or danish.

Value

a tibble

References

http://rkr.statistikbank.dk/UDB020

Examples

Run this code
# NOT RUN {
realestateDK::UDB020(BOLB20 = "4", EJKAT20 = "1", OMR20 = "00", Tid = "2004M01")
# }

Run the code above in your browser using DataLab