Learn R Programming

realestateDK (version 0.1.0)

UDB030: Supply and storage times (days)

Description

Supply and storage times (days) by area, property category, time on market and time

Usage

UDB030(BOLC20, EJKAT20, OMR20, Tid, lang = "en")

Arguments

BOLC20

is the time on market. Call realestateDK::table_vars("UDB030") to see all available parameter settings.

EJKAT20

is the property category. Call realestateDK::table_vars("UDB030") to see all available parameter settings.

OMR20

is the area. Call realestateDK::table_vars("UDB030") to see all available parameter settings.

Tid

is the time. Call realestateDK::table_vars("UDB030") to see all available parameter settings.

lang

whether to return the data in english or danish.

Value

a tibble

References

http://rkr.statistikbank.dk/UDB030

Examples

Run this code
# NOT RUN {
realestateDK::UDB030(BOLC20 = "8", EJKAT20 = "1", OMR20 = "00", Tid = "2004M01")
# }

Run the code above in your browser using DataLab