Learn R Programming

realestateDK (version 0.1.0)

UL30: Danish mortgage banks lending activity

Description

Danish mortgage banks lending activity by area, instalment, property category, loan type and time

Usage

UL30(AFDRAG, EJKAT20, LANTYP20, OMR20, Tid, lang = "en")

Arguments

AFDRAG

is the instalment. Call realestateDK::table_vars("UL30") to see all available parameter settings.

EJKAT20

is the property category. Call realestateDK::table_vars("UL30") to see all available parameter settings.

LANTYP20

is the loan type. Call realestateDK::table_vars("UL30") to see all available parameter settings.

OMR20

is the area. Call realestateDK::table_vars("UL30") to see all available parameter settings.

Tid

is the time. Call realestateDK::table_vars("UL30") to see all available parameter settings.

lang

whether to return the data in english or danish.

Value

a tibble

References

http://rkr.statistikbank.dk/UL30

Examples

Run this code
# NOT RUN {
realestateDK::UL30(AFDRAG = "0", EJKAT20 = "11", LANTYP20 = "111", OMR20 = "A", Tid = "2008K1")
# }

Run the code above in your browser using DataLab