powered by
Property prices in housing market by area, property category, prices of completed transactions and time
BM010(EJKAT20, OMR20, PRIS20, Tid, lang = "en")
is the property category. Call realestateDK::table_vars("BM010") to see all available parameter settings.
is the area. Call realestateDK::table_vars("BM010") to see all available parameter settings.
is the prices of completed transactions. Call realestateDK::table_vars("BM010") to see all available parameter settings.
is the time. Call realestateDK::table_vars("BM010") to see all available parameter settings.
whether to return the data in english or danish.
a tibble
http://rkr.statistikbank.dk/BM010
# NOT RUN { realestateDK::BM010(EJKAT20 = "1", OMR20 = "00", PRIS20 = "UDBUD", Tid = "1992K1") # }
Run the code above in your browser using DataLab