powered by
Property prices in housing market by postal code, property category, prices of completed transactions and time
BM011(EJKAT20, PNR20, PRIS20, Tid, lang = "en")
is the property category. Call realestateDK::table_vars("BM011") to see all available parameter settings.
is the postal code. Call realestateDK::table_vars("BM011") to see all available parameter settings.
is the prices of completed transactions. Call realestateDK::table_vars("BM011") to see all available parameter settings.
is the time. Call realestateDK::table_vars("BM011") to see all available parameter settings.
whether to return the data in english or danish.
a tibble
http://rkr.statistikbank.dk/BM011
# NOT RUN { realestateDK::BM011(EJKAT20 = "1", PNR20 = "1000", PRIS20 = "UDBUD", Tid = "1992K1") # }
Run the code above in your browser using DataLab