powered by
Movements in housing market by area, property category, type of movement and time
BM020(BEV20, EJKAT20, OMR20, Tid, lang = "en")
is the type of movement. Call realestateDK::table_vars("BM020") to see all available parameter settings.
is the property category. Call realestateDK::table_vars("BM020") to see all available parameter settings.
is the area. Call realestateDK::table_vars("BM020") to see all available parameter settings.
is the time. Call realestateDK::table_vars("BM020") to see all available parameter settings.
whether to return the data in english or danish.
a tibble
http://rkr.statistikbank.dk/BM020
# NOT RUN { realestateDK::BM020(BEV20 = "SALG", EJKAT20 = "1", OMR20 = "00", Tid = "2004K1") # }
Run the code above in your browser using DataLab