powered by
Housing market by area, property category, dwellings and time
UDB010(BOLA20, EJKAT20, OMR20, Tid, lang = "en")
is the dwellings. Call realestateDK::table_vars("UDB010") to see all available parameter settings.
is the property category. Call realestateDK::table_vars("UDB010") to see all available parameter settings.
is the area. Call realestateDK::table_vars("UDB010") to see all available parameter settings.
is the time. Call realestateDK::table_vars("UDB010") to see all available parameter settings.
whether to return the data in english or danish.
a tibble
http://rkr.statistikbank.dk/UDB010
# NOT RUN { realestateDK::UDB010(BOLA20 = "6", EJKAT20 = "1", OMR20 = "00", Tid = "2004M01") # }
Run the code above in your browser using DataLab