powered by
Property prices by area, property category, prices and time
UDB020(BOLB20, EJKAT20, OMR20, Tid, lang = "en")
is the prices. Call realestateDK::table_vars("UDB020") to see all available parameter settings.
is the property category. Call realestateDK::table_vars("UDB020") to see all available parameter settings.
is the area. Call realestateDK::table_vars("UDB020") to see all available parameter settings.
is the time. Call realestateDK::table_vars("UDB020") to see all available parameter settings.
whether to return the data in english or danish.
a tibble
http://rkr.statistikbank.dk/UDB020
# NOT RUN { realestateDK::UDB020(BOLB20 = "4", EJKAT20 = "1", OMR20 = "00", Tid = "2004M01") # }
Run the code above in your browser using DataLab