powered by
Supply and storage times (days) by area, property category, time on market and time
UDB030(BOLC20, EJKAT20, OMR20, Tid, lang = "en")
is the time on market. Call realestateDK::table_vars("UDB030") to see all available parameter settings.
is the property category. Call realestateDK::table_vars("UDB030") to see all available parameter settings.
is the area. Call realestateDK::table_vars("UDB030") to see all available parameter settings.
is the time. Call realestateDK::table_vars("UDB030") to see all available parameter settings.
whether to return the data in english or danish.
a tibble
http://rkr.statistikbank.dk/UDB030
# NOT RUN { realestateDK::UDB030(BOLC20 = "8", EJKAT20 = "1", OMR20 = "00", Tid = "2004M01") # }
Run the code above in your browser using DataLab