powered by
Show alle the available parameter settings for a given table id.
table_vars(table_id)
the id of the table you want to call.
a tibble
# NOT RUN { realestateDK::table_vars("BM010") # }
Run the code above in your browser using DataLab